lilypondparsertools.LilyPondFraction
====================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__repr__
   :noindex:
